.. Axelrod documentation master file, created by
   sphinx-quickstart on Sat Mar  7 07:05:57 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Tutorials
=========

This section contains a variety of tutorials related to the Axelrod library.

Contents:

.. toctree::
   :maxdepth: 2

   getting_started/index.rst
   further_topics/index.rst
   advanced/index.rst
   contributing/index.rst
